References
----------

.. [Wolf18] Wolf *et al.* (2018),
   *Scanpy: large-scale single-cell gene expression data analysis*,
   `Genome Biology <https://doi.org/10.1186/s13059-017-1382-0>`__.

.. [McInnes18] McInnes & Healy (2018),
   *UMAP: Uniform Manifold Approximation and Projection for Dimension Reduction*,
   `arXiv <https://arxiv.org/abs/1802.03426>`__.

.. [Paul15] Paul *et al.* (2015),
   *Transcriptional Heterogeneity and Lineage Commitment in Myeloid Progenitors*,
   `Cell <https://doi.org/10.1016/j.cell.2015.11.013>`__.

.. [Traag18] Traag *et al.* (2018),
   *From Louvain to Leiden: guaranteeing well-connected communities*
   `arXiv <https://arxiv.org/abs/1810.08473>`__.

.. [Waskom16] Waskom *et al.* (2017),
   *Seaborn*,
   `Zenodo <https://doi.org/10.5281/zenodo.54844>`__.
